summaryrefslogtreecommitdiffstats
path: root/qt-ui/mainwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt-ui/mainwindow.h')
-rw-r--r--qt-ui/mainwindow.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/qt-ui/mainwindow.h b/qt-ui/mainwindow.h
index 8a9d6f38b..2364caadc 100644
--- a/qt-ui/mainwindow.h
+++ b/qt-ui/mainwindow.h
@@ -67,10 +67,10 @@ public:
void showError(QString message);
void setTitle(enum MainWindowTitleFormat format);
- // The 'Change DC Shortcuts' should only be enabled
- // when the profile's visible.
- void disableDcShortcuts();
- void enableDcShortcuts();
+ // Some shortcuts like "change DC" or "copy/paste dive components"
+ // should only be enabled when the profile's visible.
+ void disableShortcuts(bool disablePaste = true);
+ void enableShortcuts();
void loadFiles(const QStringList files);
void importFiles(const QStringList importFiles);
void importTxtFiles(const QStringList fileNames);